@@ -2,8 +2,11 @@ package Catmandu::Fix::filter;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.10';
+our $VERSION = '1.2019';
 
+use Catmandu::Util qw(is_array_ref);
+use Catmandu::Util::Regex qw(as_regex);
+use Catmandu::Util::Path qw(as_path);
 use Moo;
 use namespace::clean;
 use Catmandu::Fix::Has;
@@ -12,16 +15,19 @@ has path   => (fix_arg => 1);
 has search => (fix_arg => 1);
 has invert => (fix_opt => 1);
 
-with 'Catmandu::Fix::SimpleGetValue';
+with 'Catmandu::Fix::Builder';
 
-sub emit_value {
-    my ($self, $var, $fixer) = @_;
-
-    my $match = $fixer->emit_match($self->search);
-    $match = "!$match" if $self->invert;
-
-    "if (is_array_ref(${var})) {"
-        . "${var} = [ grep { $match } \@{${var}} ];" . "}";
+sub _build_fixer {
+    my ($self) = @_;
+    my $regex  = as_regex($self->search);
+    my $cb     = $self->invert
+        ? sub {
+        [grep {!m/$regex/} @{$_[0]}];
+        }
+        : sub {
+        [grep {m/$regex/} @{$_[0]}];
+        };
+    as_path($self->path)->updater(if_array_ref => $cb);
 }
 
 1;
